# Table of Contents

- [syncing-tags-with-current-lifecycle-phases](<./syncing-tags-with-current-lifecycle-phases.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Syncing Tags with the Current Lifecycle Phases](<./Syncing-Tags-with-the-Current-Lifecycle-Phases.md>)
  - [Overview](<./Syncing-Tags-with-the-Current-Lifecycle-Phases/Overview.md>)
  - [Configuration](<./Syncing-Tags-with-the-Current-Lifecycle-Phases/Configuration.md>)
  - [Script](<./Syncing-Tags-with-the-Current-Lifecycle-Phases/Script.md>)
